NotificationAction class

Rendered as a button by default. Set contextMenu to put it under the toast's overflow menu instead.

Constructors

NotificationAction({required String content, required String arguments, NotificationActivationType activationType = NotificationActivationType.foreground, String? imageUri, String? inputId, NotificationButtonStyle? buttonStyle, bool contextMenu = false})
const

Properties

activationType NotificationActivationType
final
arguments String
final
buttonStyle NotificationButtonStyle?
final
content String
final
contextMenu bool
final
hashCode int
The hash code for this object.
no setterinherited
imageUri String?
final
inputId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited