NotificationAudio class

loop only works for Alarm / Call sounds, and only with a long-duration toast or an alarm/incomingCall scenario.

Constructors

NotificationAudio({NotificationSound? sound, bool silent = false, bool loop = false})
const
NotificationAudio.custom(String source, {bool loop = false})
const
NotificationAudio.silent()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
loop bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
silent bool
final
sound NotificationSound?
final
sourceUri String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited