NotificationCallbackDetails class

Constructors

NotificationCallbackDetails({required NotificationEvent event, required NotificationMessage message, required String? arguments, required Map<String, String> userInput})
const

Properties

arguments String?
arguments from the activated <action>, or the toast's launch value for body taps. Null on dismissal events.
final
event NotificationEvent
final
hashCode int
The hash code for this object.
no setterinherited
message NotificationMessage
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userInput Map<String, String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited