NotificationMessage class

Constructors

NotificationMessage.fromCallbackPayload(String encoded)
factory
NotificationMessage.fromCustomTemplate(String id, {String? group, String? launch, Map<String, dynamic> payload = const {}})
NotificationMessage.fromPluginTemplate(String id, String title, String body, {String? image, String? largeImage, String? heroImage, List<NotificationText> extraTexts = const [], String? attribution, String? launch, String? group, Map<String, dynamic> payload = const {}, List<NotificationAction> actions = const [], List<NotificationInput> inputs = const [], NotificationAudio? audio, NotificationProgress? progress, NotificationScenario? scenario, NotificationDuration? duration, NotificationActivationType? activationType, DateTime? displayTimestamp})

Properties

actions List<NotificationAction>
final
activationType NotificationActivationType?
Activation for clicks on the toast body itself. Defaults to NotificationActivationType.foreground; set to protocol when launch is a URL you want Windows to open.
final
attribution String?
final
audio NotificationAudio?
final
body String?
final
displayTimestamp DateTime?
final
duration NotificationDuration?
final
extraTexts List<NotificationText>
final
group String?
final
hashCode int
The hash code for this object.
no setterinherited
heroImage String?
final
id String
final
image String?
final
inputs List<NotificationInput>
final
largeImage String?
final
launch String?
final
payload Map<String, dynamic>
final
progress NotificationProgress?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scenario NotificationScenario?
final
templateType TemplateType
final
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPayloadMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited