NotificationSound enum

Names mirror the ms-winsoundevent source strings so emission can use .name directly.

Inheritance
Available extensions

Values

Default → const NotificationSound
IM → const NotificationSound
Mail → const NotificationSound
Reminder → const NotificationSound
SMS → const NotificationSound
Alarm → const NotificationSound
Alarm2 → const NotificationSound
Alarm3 → const NotificationSound
Alarm4 → const NotificationSound
Alarm5 → const NotificationSound
Alarm6 → const NotificationSound
Alarm7 → const NotificationSound
Alarm8 → const NotificationSound
Alarm9 → const NotificationSound
Alarm10 → const NotificationSound
Call → const NotificationSound
Call2 → const NotificationSound
Call3 → const NotificationSound
Call4 → const NotificationSound
Call5 → const NotificationSound
Call6 → const NotificationSound
Call7 → const NotificationSound
Call8 → const NotificationSound
Call9 → const NotificationSound
Call10 → const NotificationSound

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NotificationSound>
A constant List of the values in this enum, in order of their declaration.