NotificationText class

Constructors

NotificationText(String content, {NotificationTextStyle? style, NotificationTextAlignment? alignment, int? maxLines})
const

Properties

alignment NotificationTextAlignment?
final
content String
final
hashCode int
The hash code for this object.
no setterinherited
maxLines int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style NotificationTextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited