MethodChannelWindowsNotification class

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bringAppToForeground() Future<void>
override
clearNotificationHistory(String? applicationId) Future<void>
override
init() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerAumid({required String aumid, required String displayName, String? iconPath}) Future<void>
override
removeNotification(String id, String group, String? applicationId) Future<void>
override
removeNotificationGroup(String group, String? applicationId) Future<void>
override
setCallback(NotificationCallback? callback) Future<void>
override
showCustomTemplate(NotificationMessage message, String? applicationId, String template) Future<void>
override
showPluginTemplate(NotificationMessage message, String? applicationId) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited