WindowsNotificationPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- WindowsNotificationPlatform
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bringAppToForeground(
) → Future< void> -
clearNotificationHistory(
String? applicationId) → Future< void> -
init(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerAumid(
{required String aumid, required String displayName, String? iconPath}) → Future< void> -
removeNotification(
String id, String group, String? applicationId) → Future< void> -
removeNotificationGroup(
String group, String? applicationId) → Future< void> -
setCallback(
NotificationCallback? callback) → Future< void> -
showCustomTemplate(
NotificationMessage message, String? applicationId, String template) → Future< void> -
showPluginTemplate(
NotificationMessage message, String? applicationId) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ WindowsNotificationPlatform
-
getter/setter pair