NotificationInput class

A text input or selection list shown inside a toast. Link to an action button with NotificationAction.inputId to get a send-reply pairing.

Constructors

NotificationInput.selection({required String id, required List<NotificationSelection> selections, String? title, String? defaultSelectionId})
const
NotificationInput.text({required String id, String? title, String? placeholder})
const

Properties

defaultSelectionId String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
placeholder String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selections List<NotificationSelection>
final
title String?
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited