NotificationProgress class

value is null for indeterminate, otherwise clamped to [0.0, 1.0].

Constructors

NotificationProgress({String? title, double? value, String? valueStringOverride, String status = ''})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
title String?
final
value double?
final
valueStringOverride String?
Replaces the default 35% readout. e.g. '12 of 34'.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited